@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022 Red Hat
+ * Copyright (C) 2023 Red Hat
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
@@ -944,11 +944,6 @@ pgagroal_validate_configuration(void* shm, bool has_unix_socket, bool has_main_s
             pgagroal_log_fatal("pgagroal: Transaction pipeline does not support allow_unknown_users");
             return 1;
          }
-
-         if (config->number_of_limits == 0)
-         {
-            pgagroal_log_info("pgagroal: Defining limits for the transaction pipeline is recommended");
-         }
       }
 
       for (int i = 0; i < config->number_of_servers; i++)
@@ -960,6 +955,33 @@ pgagroal_validate_configuration(void* shm, bool has_unix_socket, bool has_main_s
          }
       }
 
+      if (config->number_of_limits == 0)
+      {
+         pgagroal_log_fatal("pgagroal: Defining limits for the transaction pipeline is mandatory");
+         return 1;
+      }
+
+      for (int i = 0; i < config->number_of_limits; i++)
+      {
+         if (config->limits[i].min_size <= 0)
+         {
+            pgagroal_log_fatal("pgagroal: min_size for transaction pipeline must be greater than 0");
+            return 1;
+         }
+
+         if (config->limits[i].initial_size <= 0)
+         {
+            pgagroal_log_fatal("pgagroal: initial_size for transaction pipeline must be greater than 0");
+            return 1;
+         }
+
+         if (config->limits[i].max_size <= 0)
+         {
+            pgagroal_log_fatal("pgagroal: max_size for transaction pipeline must be greater than 0");
+            return 1;
+         }
+      }
+
       if (config->blocking_timeout > 0)
       {
          pgagroal_log_warn("pgagroal: Using blocking_timeout for the transaction pipeline is not recommended");
@@ -1360,6 +1382,12 @@ pgagroal_read_users_configuration(void* shm, char* filename)
 
          ptr = strtok(NULL, ":");
 
+         if (ptr == NULL)
+         {
+            status = PGAGROAL_CONFIGURATION_STATUS_CANNOT_DECRYPT;
+            goto error;
+         }
+
          if (pgagroal_base64_decode(ptr, strlen(ptr), &decoded, &decoded_length))
          {
             status = PGAGROAL_CONFIGURATION_STATUS_CANNOT_DECRYPT;
@@ -1476,6 +1504,12 @@ pgagroal_read_frontend_users_configuration(void* shm, char* filename)
 
          ptr = strtok(NULL, ":");
 
+         if (ptr == NULL)
+         {
+            status = PGAGROAL_CONFIGURATION_STATUS_CANNOT_DECRYPT;
+            goto error;
+         }
+
          if (pgagroal_base64_decode(ptr, strlen(ptr), &decoded, &decoded_length))
          {
             status = PGAGROAL_CONFIGURATION_STATUS_CANNOT_DECRYPT;
@@ -1617,6 +1651,12 @@ pgagroal_read_admins_configuration(void* shm, char* filename)
 
          ptr = strtok(NULL, ":");
 
+         if (ptr == NULL)
+         {
+            status = PGAGROAL_CONFIGURATION_STATUS_CANNOT_DECRYPT;
+            goto error;
+         }
+
          if (pgagroal_base64_decode(ptr, strlen(ptr), &decoded, &decoded_length))
          {
             status = PGAGROAL_CONFIGURATION_STATUS_CANNOT_DECRYPT;
@@ -1745,6 +1785,12 @@ pgagroal_read_superuser_configuration(void* shm, char* filename)
 
          ptr = strtok(NULL, ":");
 
+         if (ptr == NULL)
+         {
+            status = PGAGROAL_CONFIGURATION_STATUS_CANNOT_DECRYPT;
+            goto error;
+         }
+
          if (pgagroal_base64_decode(ptr, strlen(ptr), &decoded, &decoded_length))
          {
             status = PGAGROAL_CONFIGURATION_STATUS_CANNOT_DECRYPT;
